/*
 *******************************************************************************
 *
 *  Copyright 2024 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
#define RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1

// Meta data item definition version
const char* const RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const char* const RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
typedef struct MetaDataItemInfo
{
    const char*   name;
    const char*   title;
    const char*   description;
    unsigned char status;
    const char*   schema;
    const char*   example;
} MetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"angle\":{\"type\":\"array\",\"description\":\""
    "Angle [deg]\",\"items\":{\"type\":\"number\"}},\"amplitude_mean\":{\"type\":\"arra"
    "y\",\"description\":\"Mean amplitude [dB]\",\"items\":{\"type\":\"number\"}},\"ran"
    "ge_mean\":{\"type\":\"array\",\"description\":\"Mean range "
    "[m]\",\"items\":{\"type\":\"number\"}}},\"title\":\"Angular Notch "
    "Filter\",\"description\":\"Angular notch filter parameters for window "
    "glass echoes\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"req"
    "uired\":[\"angle\",\"range_mean\",\"amplitude_mean\"]}"
    ,
    /* example: */
    "{\"angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],\"amp"
    "litude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.720913,2."
    "680913,2.610913,2.530913,2.570913,2.570913],\"range_mean\":[0.094,0.094,"
    "0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"wavelength\":{\"type\":\"number\",\"descript"
    "ion\":\"Laser wavelength "
    "[nm]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean sea "
    "level (AMSL) [m]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure"
    " along measurment path "
    "[mbar]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature "
    "along measurement path "
    "[\\u00b0C]\"},\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "attenuation "
    "[1/km]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level [mbar]\"}},\"title\":\"Atmospheric "
    "Parameters\",\"description\":\"Atmospheric parameters\",\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"required\":[\"temperature\",\"pressure\","
    "\"rel_humidity\",\"pressure_sl\",\"amsl\",\"group_velocity\",\"attenuation\",\"wa"
    "velength\"]}"
    ,
    /* example: */
    "{\"wavelength\":1550,\"amsl\":0,\"pressure\":970,\"group_velocity\":299711000."
    "0,\"temperature\":7,\"attenuation\":0.028125,\"rel_humidity\":63,\"pressure_s"
    "l\":970}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"beam_exit_diameter\":{\"type\":\"number\",\""
    "description\":\"Beam width at exit aperture [m]\",\"exclusiveMinimum\":fals"
    "e,\"minimum\":0},\"beam_divergence\":{\"type\":\"number\",\"description\":\"Beam "
    "divergence in far field "
    "[rad]\",\"exclusiveMinimum\":false,\"minimum\":0}},\"title\":\"Beam "
    "Geometry\",\"description\":\"Laser beam geometry details\",\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"required\":[\"beam_exit_diameter\",\""
    "beam_divergence\"]}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"types\":{\"type\":\"array\",\"uniqueItems\":t"
    "rue,\"items\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/rectangle"
    "\"},{\"$ref\":\"#/definitions/checkerboard2x2\"},{\"$ref\":\"#/definitions/che"
    "vron\"},{\"$ref\":\"#/definitions/circular_disk\"},{\"$ref\":\"#/definitions/c"
    "ylinder\"},{\"$ref\":\"#/definitions/sphere\"},{\"$ref\":\"#/definitions/round"
    "_corner_cube_prism\"}]}}},\"title\":\"Control Object Catalog\",\"definitions"
    "\":{\"cylinder\":{\"type\":\"object\",\"description\":\"cylinder\",\"allOf\":[{\"$re"
    "f\":\"#/definitions/common\"},{\"type\":\"object\",\"description\":\"cylinder "
    "specific properties\",\"required\":[\"shape\",\"diameter\",\"height\"],\"propert"
    "ies\":{\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"enum\""
    ":[\"cylinder\"]},\"diameter\":{\"type\":\"number\",\"description\":\"diameter in "
    "meters\",\"exclusiveMinimum\":true,\"minimum\":0},\"height\":{\"type\":\"number\""
    ",\"description\":\"height in meters\",\"exclusiveMinimum\":true,\"minimum\":0}"
    "}}]},\"common\":{\"type\":\"object\",\"description\":\"common object properties"
    "\",\"required\":[\"name\",\"shape\"],\"properties\":{\"shape\":{\"type\":\"string\",\""
    "description\":\"shape identifier\",\"enum\":[\"rectangle\",\"checkerboard2x2\","
    "\"chevron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner_cube_prism"
    "\"]},\"description\":{\"type\":\"string\",\"description\":\"string describing "
    "the object\"},\"name\":{\"type\":\"string\",\"description\":\"unique type identi"
    "fier\",\"minLength\":3},\"surface_type\":{\"type\":\"string\",\"description\":\"su"
    "rface material type\",\"enum\":[\"retro_reflective_foil\",\"diffuse\"]}}},\"ch"
    "evron\":{\"type\":\"object\",\"description\":\"chevron\",\"allOf\":[{\"$ref\":\"#/de"
    "finitions/common\"},{\"type\":\"object\",\"description\":\"chevron specific pr"
    "operties\",\"required\":[\"shape\",\"outside_edge_length\",\"thickness\"],\"prop"
    "erties\":{\"shape\":{\"type\":\"string\",\"description\":\"shape identifier\",\"en"
    "um\":[\"chevron\"]},\"thickness\":{\"type\":\"number\",\"description\":\"thickness"
    " in meters\",\"exclusiveMinimum\":true,\"minimum\":0},\"outside_edge_length\""
    ":{\"type\":\"number\",\"description\":\"length of the two outer edges in mete"
    "rs\",\"exclusiveMinimum\":true,\"minimum\":0}}}]},\"round_corner_cube_prism\""
    ":{\"type\":\"object\",\"description\":\"round corner cube prism\",\"allOf\":[{\"$"
    "ref\":\"#/definitions/common\"},{\"type\":\"object\",\"description\":\"round "
    "corner cube prism specific properties\",\"required\":[\"shape\",\"diameter\"]"
    ",\"properties\":{\"shape\":{\"type\":\"string\",\"description\":\"shape identifie"
    "r\",\"enum\":[\"round_corner_cube_prism\"]},\"diameter\":{\"type\":\"number\",\"de"
    "scription\":\"diameter in meters\",\"exclusiveMinimum\":true,\"minimum\":0},\""
    "offset\":{\"type\":\"number\",\"description\":\"offset in meters, e.g. "
    "reflector constant (optional)\"}}}]},\"circular_disk\":{\"type\":\"object\",\""
    "description\":\"circular disk\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},"
    "{\"type\":\"object\",\"description\":\"circular disk specific properties\",\"re"
    "quired\":[\"shape\",\"diameter\"],\"properties\":{\"shape\":{\"type\":\"string\",\"d"
    "escription\":\"shape identifier\",\"enum\":[\"circular_disk\"]},\"diameter\":{\""
    "type\":\"number\",\"description\":\"diameter in meters\",\"exclusiveMinimum\":t"
    "rue,\"minimum\":0},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"}}}]},\"sphere\":{\"type\":\"obj"
    "ect\",\"description\":\"sphere\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{"
    "\"type\":\"object\",\"description\":\"sphere specific properties\",\"required\":"
    "[\"shape\",\"diameter\"],\"properties\":{\"shape\":{\"type\":\"string\",\"descripti"
    "on\":\"shape identifier\",\"enum\":[\"sphere\"]},\"diameter\":{\"type\":\"number\","
    "\"description\":\"diameter in meters\",\"exclusiveMinimum\":true,\"minimum\":0"
    "}}}]},\"checkerboard2x2\":{\"type\":\"object\",\"description\":\"checkerboard 2"
    " by 2\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"desc"
    "ription\":\"checkerboard specific properties\",\"required\":[\"shape\",\"squar"
    "e_length\"],\"properties\":{\"shape\":{\"type\":\"string\",\"description\":\"shape"
    " identifier\",\"enum\":[\"checkerboard2x2\"]},\"square_length\":{\"type\":\"numb"
    "er\",\"description\":\"length of a square of the checkerboard in meters\",\""
    "exclusiveMinimum\":true,\"minimum\":0}}}]},\"rectangle\":{\"type\":\"object\",\""
    "description\":\"rectangle\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"ty"
    "pe\":\"object\",\"description\":\"rectangle specific properties\",\"required\":"
    "[\"shape\",\"length\",\"width\"],\"properties\":{\"shape\":{\"type\":\"string\",\"enu"
    "m\":[\"rectangle\"]},\"width\":{\"type\":\"number\",\"description\":\"width in met"
    "ers\",\"exclusiveMinimum\":true,\"minimum\":0},\"length\":{\"type\":\"number\",\"d"
    "escription\":\"length in "
    "meters\",\"exclusiveMinimum\":true,\"minimum\":0}}}]}},\"description\":\"List "
    "of control object type definitions\",\"$schema\":\"http://json-schema.org/"
    "draft-04/schema#\",\"required\":[\"types\"]}"
    ,
    /* example: */
    "{\"types\":[{\"shape\":\"rectangle\",\"description\":\"Rectangle (60cm x "
    "30cm)\",\"width\":0.3,\"name\":\"Rectangle "
    "60x30\",\"length\":0.6},{\"shape\":\"rectangle\",\"description\":\"Rectangle "
    "(80cm x 40cm)\",\"width\":0.4,\"name\":\"Rectangle 80x40\",\"length\":0.8},{\"sh"
    "ape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square length: "
    "30cm)\",\"name\":\"Checkerboard2x2 30\",\"square_length\":0.3},{\"shape\":\"chec"
    "kerboard2x2\",\"description\":\"Checkerboard (square length: "
    "50cm)\",\"name\":\"Checkerboard2x2 "
    "50\",\"square_length\":0.5},{\"shape\":\"chevron\",\"description\":\"Chevron "
    "(a=24''; b=4'')\",\"outside_edge_length\":0.6096,\"name\":\"Chevron "
    "24''/4''\",\"thickness\":0.1016},{\"shape\":\"circular_disk\",\"description\":\""
    " Circular Disk (diameter: 50cm)\",\"diameter\":0.5,\"name\":\"Circular Disk "
    "50\",\"surface_type\":\"diffuse\"},{\"shape\":\"circular_disk\",\"diameter\":0.05"
    ",\"offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"name\":\"RIEGL flat reflector 50 mm\",\"surface_ty"
    "pe\":\"retro_reflective_foil\"},{\"shape\":\"circular_disk\",\"diameter\":0.1,\""
    "offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"name\":\"RIEGL flat reflector 100 mm\",\"surface_t"
    "ype\":\"retro_reflective_foil\"},{\"shape\":\"circular_disk\",\"diameter\":0.15"
    ",\"offset\":0.0,\"description\":\"flat circular reflector from "
    "retro-reflective foil\",\"name\":\"RIEGL flat reflector 150 mm\",\"surface_t"
    "ype\":\"retro_reflective_foil\"},{\"shape\":\"cylinder\",\"diameter\":0.05,\"hei"
    "ght\":0.05,\"description\":\"cylindrical reflector from retro-reflective "
    "foil\",\"name\":\"RIEGL cylindrical reflector 50 mm\",\"surface_type\":\"retro"
    "_reflective_foil\"},{\"shape\":\"cylinder\",\"diameter\":0.1,\"height\":0.1,\"de"
    "scription\":\"cylindrical reflector from retro-reflective "
    "foil\",\"name\":\"RIEGL cylindrical reflector 100 mm\",\"surface_type\":\"retr"
    "o_reflective_foil\"},{\"shape\":\"sphere\",\"description\":\"Sphere (diameter:"
    " 200 mm)\",\"diameter\":0.2,\"name\":\"Sphere 200 "
    "mm\"},{\"shape\":\"round_corner_cube_prism\",\"description\":\"round corner "
    "cube prism\",\"diameter\":0.05,\"name\":\"Corner Cube Prism 50 "
    "mm\",\"offset\":0.0}],\"comments\":[\"This file contains a list of control "
    "object types (aka. 'catalog').\",\"Each type is described by an "
    "object,\",\"which must contain at least the following parameters:\",\"  - "
    "name: unique identifier of the type\",\"  - shape: one of the following "
    "supported shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\""
    "      - chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - "
    "sphere\",\"      - round_corner_cube_prism\",\"Depending on 'shape', the "
    "following parameters must/may be specified:\",\"  - rectangle:\",\"      -"
    " length: length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or 'diffuse')\"]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about the control object "
    "reference file\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"p"
    "roperties\":{\"reference_file\":{\"type\":\"object\",\"description\":\"Reference"
    " to a control object file\",\"required\":[\"file_uuid\",\"file_path\"],\"prope"
    "rties\":{\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring "
    "file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Control object "
    "file's Universally Unique Identifier (RFC 4122)\"}}}},\"title\":\"Control "
    "Object Reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoi"
    "nts.cpx\",\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"amplitude\":{\"type\":\"array\",\"descriptio"
    "n\":\"Amplitude [dB]\",\"items\":{\"type\":\"number\"}},\"detection_probability\""
    ":{\"type\":\"array\",\"description\":\"Detection probability "
    "[0..1]\",\"items\":{\"type\":\"number\"}}},\"title\":\"Detection "
    "Probability\",\"description\":\"Detection probability as a function of amp"
    "litude\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\""
    ":[\"amplitude\",\"detection_probability\"]}"
    ,
    /* example: */
    "{\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],\"detection"
    "_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"channel_number\":{\"type\":\"integer\",\"des"
    "cription\":\"Laser channel number (not defined or 0: single channel devi"
    "ce)\",\"exclusiveMinimum\":false,\"minimum\":0},\"serial_number\":{\"type\":\"st"
    "ring\",\"description\":\"Device serial number (e.g. "
    "S2221234)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"}},\"title\":\"Device Information\",\"description\":\"Details about "
    "the device used to acquire the point cloud\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"required\":[\"device_type\",\"serial_number\"]}"
    ,
    /* example: */
    "{\"channel_number\":0,\"serial_number\":\"S2221234\",\"device_type\":\"VZ-400i\""
    ",\"channel_text\":\"\",\"device_build\":\"\",\"device_name\":\"Scanner 1\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"secondary\":{\"type\":\"object\",\"descripti"
    "on\":\"Additional device geometry structure (optional)\",\"required\":[\"ID\""
    ",\"content\"],\"properties\":{\"content\":{\"type\":\"array\",\"description\":\"Int"
    "ernal calibration values\",\"items\":{\"type\":\"number\"}},\"ID\":{\"type\":\"arr"
    "ay\",\"description\":\"Structure identifier\",\"minItems\":2,\"maxItems\":2,\"it"
    "ems\":{\"type\":\"integer\"}}}},\"primary\":{\"type\":\"object\",\"description\":\"P"
    "rimary device geometry structure (mandatory)\",\"required\":[\"ID\",\"conten"
    "t\"],\"properties\":{\"content\":{\"type\":\"array\",\"description\":\"Internal "
    "calibration values\",\"items\":{\"type\":\"number\"}},\"ID\":{\"type\":\"array\",\"d"
    "escription\":\"Structure identifier\",\"minItems\":2,\"maxItems\":2,\"items\":{"
    "\"type\":\"integer\"}}}},\"amu\":{\"type\":\"object\",\"description\":\"Angle "
    "Measurement "
    "Unit\",\"properties\":{\"lineCC\":{\"type\":\"number\",\"description\":\"Line "
    "Circle Count (number of LSBs per full rotation about line axis)\",\"excl"
    "usiveMinimum\":false,\"minimum\":0},\"frameCC\":{\"type\":\"number\",\"descripti"
    "on\":\"Frame Circle Count (number of LSBs per full rotation about frame "
    "axis)\",\"exclusiveMinimum\":false,\"minimum\":0}}}},\"title\":\"Device "
    "Geometry\",\"description\":\"Scanner device geometry details\",\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"secondary\":{\"content\":[0],\"ID\":[91,0]},\"primary\":{\"content\":[0],\"ID\""
    ":[4,0]},\"amu\":{\"lineCC\":124000,\"frameCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"primary\":{\"type\":\"object\",\"description"
    "\":\"Primary device geometry structure (mandatory)\",\"required\":[\"ID\",\"co"
    "ntent\"],\"properties\":{\"content\":{\"type\":\"array\",\"description\":\"Interna"
    "l calibration values\",\"items\":{\"type\":\"number\"}},\"ID\":{\"type\":\"array\","
    "\"description\":\"Structure identifier\",\"minItems\":2,\"maxItems\":2,\"items\""
    ":{\"type\":\"integer\"}}}}},\"title\":\"Device Geometry Passive "
    "Channel\",\"description\":\"Scanner passive channel device geometry detail"
    "s\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"pr"
    "imary\"]}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Limits of the measured values output "
    "by the device. The limits depend on the device type, measurement "
    "program and/or scan pattern.\",\"$schema\":\"http://json-schema.org/draft-"
    "04/schema#\",\"properties\":{\"deviation_maximum\":{\"type\":\"number\",\"descri"
    "ption\":\"Maximum possible pulse shape deviation.\"},\"background_radiatio"
    "n_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible background"
    " radiation.\"},\"reflectance_maximum\":{\"type\":\"number\",\"description\":\"Ma"
    "ximum possible reflectance in "
    "dB.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"},\"echo_count_maximum\":{\"type\":\"number"
    "\",\"description\":\"Maximum number of echoes a laser shot can have.\"},\"mt"
    "a_zone_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum number "
    "of MTA "
    "zones.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible range in "
    "meters.\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible amplitude in "
    "dB.\"},\"reflectance_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible reflectance in "
    "dB.\"},\"amplitude_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible amplitude in dB.\"},\"background_radiation_minimum\":{\"type\":\"nu"
    "mber\",\"description\":\"Minimum possible background "
    "radiation.\"},\"range_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible range in meters.\"}},\"title\":\"Device Output Limits\"}"
    ,
    /* example: */
    "{\"range_maximum\":10000.0,\"amplitude_maximum\":100.0,\"reflectance_minimu"
    "m\":-100.0,\"amplitude_minimum\":0.0,\"background_radiation_minimum\":0,\"ba"
    "ckground_radiation_maximum\":0,\"reflectance_maximum\":100.0,\"deviation_m"
    "inimum\":-1,\"deviation_maximum\":32767,\"mta_zone_count_maximum\":7,\"range"
    "_minimum\":2.9}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"description\":\"Details about the devices used to "
    "acquire the point cloud (e.g. when merging point clouds of different d"
    "evices)\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\""
    "Devices Information\",\"items\":{\"type\":\"object\",\"properties\":{\"channel_n"
    "umber\":{\"type\":\"integer\",\"description\":\"Laser channel number (not "
    "defined or 0: single channel device)\",\"exclusiveMinimum\":false,\"minimu"
    "m\":0},\"serial_number\":{\"type\":\"string\",\"description\":\"Device serial "
    "number (e.g. "
    "S2221234)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set "
    "when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"}},\"required\":[\"device_type\",\"serial_number\"]}}"
    ,
    /* example: */
    "[{\"channel_number\":0,\"serial_number\":\"S2221234\",\"device_type\":\"VZ-400i"
    "\",\"signed\":false,\"channel_text\":\"\",\"device_build\":\"\",\"device_name\":\"Sc"
    "anner 1\"},{\"channel_number\":1,\"serial_number\":\"S2222680\",\"device_type\""
    ":\"VQ-1560i-DW\",\"signed\":true,\"channel_text\":\"\",\"device_build\":\"\",\"devi"
    "ce_name\":\"Scanner 2\"},{\"channel_number\":2,\"serial_number\":\"S2222680\",\""
    "device_type\":\"VQ-1560i-DW\",\"signed\":true,\"channel_text\":\"\",\"device_bui"
    "ld\":\"\",\"device_name\":\"Scanner 3\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"pre\":{\"type\":\"object\",\"description\":\"Dyntrig pre value"
    "s\",\"required\":[\"nc\",\"a\"],\"properties\":{\"nc\":{\"type\":\"integer\",\"maximum"
    "\":255,\"minimum\":0,\"description\":\"Number of entries\"},\"a\":{\"type\":\"arra"
    "y\",\"description\":\"...\",\"minItems\":1,\"maxItems\":2080,\"items\":{\"type\":\"n"
    "umber\"}}}},\"offset\":{\"type\":\"number\",\"description\":\"Offset in units of"
    " dB, for calculation of "
    "line\"},\"post\":{\"type\":\"object\",\"description\":\"Dyntrig post values\",\"re"
    "quired\":[\"nc\",\"a\"],\"properties\":{\"nc\":{\"type\":\"integer\",\"maximum\":255,"
    "\"minimum\":0,\"description\":\"Number of entries\"},\"a\":{\"type\":\"array\",\"de"
    "scription\":\"...\",\"minItems\":1,\"maxItems\":2080,\"items\":{\"type\":\"number\""
    "}}}},\"scale\":{\"type\":\"number\",\"description\":\"Scale in units of dB, for"
    " calculation of line: line number N=(amplitude-offset)/scale\"},\"tab\":{"
    "\"type\":\"array\",\"description\":\"...\",\"minItems\":1,\"maxItems\":128,\"items\""
    ":{\"type\":\"object\",\"description\":\"...\",\"required\":[\"thra1\",\"del1\",\"dec1"
    "\",\"thra2\",\"del2\",\"dec2\"],\"properties\":{\"del1\":{\"type\":\"number\",\"descri"
    "ption\":\"Length of constant post-trigger threshold elevation in units "
    "of m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold "
    "in units of dB\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of "
    "post-trigger threshold after del1 in units of "
    "dB/m\"},\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger threshold "
    "in units of dB\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise of "
    "pre-trigger threshold after del2 in units of "
    "dB/m\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of constant "
    "pre-trigger threshold elevation in units of m\"}}}}},\"description\":\"Dyn"
    "trig\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Dyn"
    "trig\"}"
    ,
    /* example: */
    "{\"pre\":{\"nc\":128,\"a\":[78,86,126,134,31]},\"offset\":0.0,\"post\":{\"nc\":128"
    ",\"a\":[78,86,126,134,31]},\"scale\":1.0,\"tab\":[{\"del1\":0.0,\"thra1\":0.0,\"d"
    "ec1\":0.0,\"thra2\":0.0,\"dec2\":0.0,\"del2\":0.0}]}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"echo_file\":{\"type\":\"object\",\"propertie"
    "s\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"title\":\"Echo "
    "Information\",\"description\":\"Details about echo files\",\"$schema\":\"http:"
    "//json-schema.org/draft-04/schema#\",\"required\":[\"echo_file\"]}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\"description\":\"one "
    "field per channel, field name is channel "
    "index\",\"$ref\":\"#/definitions/channel\"}},\"title\":\"Exponential Decomposi"
    "tion\",\"definitions\":{\"channel\":{\"type\":\"object\",\"properties\":{\"delay\":"
    "{\"type\":\"number\",\"description\":\"delay calibration in "
    "seconds\"},\"scale\":{\"type\":\"number\",\"description\":\"amplitude calibratio"
    "n\"},\"a_lin\":{\"type\":\"number\",\"maximum\":1,\"minimum\":0,\"exclusiveMinimum"
    "\":false,\"description\":\"relative linear amplitude range [0..1]\",\"exclus"
    "iveMaximum\":false},\"parameter\":{\"type\":\"object\",\"description\":\"paramet"
    "ers of the syswave exponential sum\",\"required\":[\"A\",\"B\",\"gamma\",\"omega"
    "\"],\"properties\":{\"gamma\":{\"type\":\"array\",\"description\":\"decay in 1/sec"
    "ond\",\"items\":{\"type\":\"number\"}},\"A\":{\"type\":\"array\",\"description\":\"rea"
    "l part of amplitude factor in units of full-scale\",\"items\":{\"type\":\"nu"
    "mber\"}},\"B\":{\"type\":\"array\",\"description\":\"imaginary part of amplitude"
    " factor in units of full-scale\",\"items\":{\"type\":\"number\"}},\"omega\":{\"t"
    "ype\":\"array\",\"description\":\"angular frequency in Hz\",\"items\":{\"type\":\""
    "number\"}}}}},\"required\":[\"delay\",\"scale\",\"parameter\"]}},\"additionalPro"
    "perties\":false,\"description\":\"Details for exponential decomposition of"
    " full waveform "
    "data\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"0\":{\"delay\":3.783458418887631e-09,\"scale\":1.0,\"a_lin\":0.27,\"paramete"
    "r\":{\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\"A\":[0.977245092"
    "3919678,0.3354335129261017,-1.312678575515747],\"B\":[-3.981303215026855"
    "5,0.08622030913829803,-0.3152860999107361],\"omega\":[352020896.0,364792"
    "7552.0,-1977987072.0]}},\"1\":{\"delay\":3.5e-09,\"scale\":1.0,\"a_lin\":0.9,\""
    "parameter\":{\"gamma\":[-1094726528.0,-769562752.0,-848000064.0],\"A\":[0.9"
    ",0.3,-1.3],\"B\":[-3.9,0.0,-0.3],\"omega\":[352020896.0,3647927552.0,-1977"
    "987072.0]}}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"range_offset_sec_low_power\":{\"type\":\"a"
    "rray\",\"items\":{\"type\":\"number\"}},\"amplitude_lsb_low_power\":{\"type\":\"ar"
    "ray\",\"items\":{\"type\":\"number\"}},\"amplitude_db\":{\"type\":\"array\",\"items\""
    ":{\"type\":\"number\"}},\"range_offset_sec_high_power\":{\"type\":\"array\",\"ite"
    "ms\":{\"type\":\"number\"}},\"amplitude_lsb_high_power\":{\"type\":\"array\",\"ite"
    "ms\":{\"type\":\"number\"}}},\"title\":\"Gaussian "
    "Decomposition\",\"description\":\"riegl.gaussian_decomposition contains "
    "information relevant for extracting calibrated amplitudes and "
    "calibrated ranges from a Gaussian decomposition of full waveform data."
    " This information is contained in a table with five columns. Two "
    "columns are to be used as input: amplitude_lsb_low_power and "
    "amplitude_lsb_high_power. The other three columns provide the outputs."
    " Amplitude_db gives the calibrated amplitude in the optical regime in "
    "decibels. The range offset columns provide additive range offsets, "
    "given in units of seconds, for each channel.\",\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"required\":[\"amplitude_lsb_low_power\",\"amp"
    "litude_lsb_high_power\",\"amplitude_db\",\"range_offset_sec_low_power\",\"ra"
    "nge_offset_sec_high_power\"]}"
    ,
    /* example: */
    "{\"range_offset_sec_low_power\":[],\"amplitude_lsb_low_power\":[],\"amplitu"
    "de_db\":[],\"range_offset_sec_high_power\":[],\"amplitude_lsb_high_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Point cloud georeferencing information"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"c"
    "rs\":{\"type\":\"object\",\"description\":\"Global Coordinate Reference "
    "System. Please note that only 3D Cartesian Coordinate Systems are allo"
    "wed.\",\"properties\":{\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known"
    " Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/sta"
    "ndards/wkt-crs)\"},\"name\":{\"type\":\"string\",\"description\":\"Coordinate "
    "reference system name\"},\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG "
    "code\",\"minimum\":0}}},\"pose\":{\"type\":\"array\",\"description\":\"Coordinate "
    "Transformation Matrix to transform from File Coordinate System to "
    "Global Coordinate Reference System. 4x4 matrix stored as two "
    "dimensional array, row major order.\",\"minItems\":4,\"maxItems\":4,\"items\""
    ":{\"type\":\"array\",\"description\":\"rows\",\"minItems\":4,\"maxItems\":4,\"items"
    "\":{\"type\":\"number\",\"description\":\"columns\"}}}},\"title\":\"Geo Tag\"}"
    ,
    /* example: */
    "{\"crs\":{\"wkt\":\"GEOCCS[\\\"WGS84 Geocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\""
    "WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHOR"
    "ITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Meter\\\",1.00000000000000000000,AUTHORIT"
    "Y[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NO"
    "RTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\"]]\",\"name\":\"WGS84 Geocentric\",\"epsg\":4"
    "978},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"number\",\"description\":\"Geometric scale factor applied to "
    "point coordinates\",\"$schema\":\"http://json-schema.org/draft-04/schema#\""
    ",\"exclusiveMinimum\":true,\"minimum\":0}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Parameters used for georeferencing of "
    "the point cloud\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\""
    "properties\":{\"trajectory_file\":{\"type\":\"object\",\"description\":\"Traject"
    "ory data used for georeferencing of the point cloud\",\"required\":[\"file"
    "_extension\"],\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":"
    "\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading dot\"}}},\"trajectory_offsets\":{\"typ"
    "e\":\"object\",\"description\":\"Correction offsets applied to the "
    "trajectory data\",\"properties\":{\"offset_north\":{\"type\":\"number\",\"descri"
    "ption\":\"[m]\"},\"version\":{\"type\":\"integer\",\"description\":\"Meaning of "
    "offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_roll\":{\"type\":\"number\",\"description\":\"[deg"
    "]\"},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\"},\"offset_east\":"
    "{\"type\":\"number\",\"description\":\"[m]\"},\"offset_pitch\":{\"type\":\"number\","
    "\"description\":\"[deg]\"},\"offset_height\":{\"type\":\"number\",\"description\":"
    "\"[m]\"},\"offset_yaw\":{\"type\":\"number\",\"description\":\"[deg]\"}}},\"socs_to"
    "_rocs_matrix\":{\"type\":\"array\",\"description\":\"Coordinate Transformation"
    " Matrix to transform from Scanner's Own Coordinate System to Record "
    "Coordinate System. 4x4 matrix stored as two dimensional array, row "
    "major order.\",\"minItems\":4,\"maxItems\":4,\"items\":{\"type\":\"array\",\"descr"
    "iption\":\"rows\",\"minItems\":4,\"maxItems\":4,\"items\":{\"type\":\"number\",\"des"
    "cription\":\"columns\"}}},\"socs_to_body_matrix\":{\"type\":\"array\",\"descript"
    "ion\":\"Coordinate Transformation Matrix to transform from Scanner's Own"
    " Coordinate System to Body Coordinate System. 4x4 matrix stored as two"
    " dimensional array, row major order.\",\"minItems\":4,\"maxItems\":4,\"items"
    "\":{\"type\":\"array\",\"description\":\"rows\",\"minItems\":4,\"maxItems\":4,\"item"
    "s\":{\"type\":\"number\",\"description\":\"columns\"}}},\"body_coordinate_system"
    "_type\":{\"type\":\"string\",\"description\":\"BODY coordinate frame (NED: "
    "North-East-Down, ENU: East-North-Up), default: "
    "NED\",\"enum\":[\"NED\",\"ENU\"]}},\"title\":\"Georeferencing Parameters\"}"
    ,
    /* example: */
    "{\"trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\""
    ",\"file_extension\":\"pofx\"},\"trajectory_offsets\":{\"offset_north\":0.07,\"v"
    "ersion\":0,\"offset_roll\":0.03,\"offset_time\":18.007,\"offset_east\":0.15,\""
    "offset_pitch\":0.01,\"offset_height\":-0.2,\"offset_yaw\":-0.45},\"socs_to_b"
    "ody_matrix\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "0.0],[0.962908599449764,-0.20260517250352,0.178208229833847,0.0],[0.0,"
    "0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],\"body_coordi"
    "nate_system_type\":\"NED\"}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"d"
    "escription\":\"One field per item, field name is item id, field value is"
    " item name\"}},\"title\":\"Item "
    "Names\",\"additionalProperties\":false,\"description\":\"Map of item "
    "names\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"-1\":\"Name of item with id -1\",\"47\":\"Name of item with id "
    "47\",\"1\":\"Name of item with id 1\",\"2\":\"Name of item with id 2\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"descript"
    "ion\":\"Each field of the object represents a feature and holds a list "
    "of license keys, where the field name is the feature "
    "name.\",\"minItems\":1,\"items\":{\"type\":\"string\",\"description\":\"License "
    "key (example: '46AE032A - 39882AC4 - 9EC0A184 - "
    "6F163D73')\"}}},\"title\":\"Software License "
    "Keys\",\"additionalProperties\":false,\"description\":\"License keys for "
    "software "
    "features\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"Georeferencing\":[\"46AE032A - 39882AC4 - 9EC0A184 - 6F163D73\"],\"Full "
    "Waveform Analysis Topography with GPU support\":[\"8AB44126 - 23B92250 -"
    " 16E2689F - 34EF7E7B\"],\"Full Waveform Analysis Topography\":[\"0FD5FF07 "
    "- 011A1255 - 9F76CACA - 8D2ED557\"],\"MTA resolution\":[\"468E020A - "
    "39A922E4 - B681A184 - 673E3D72\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Parameters for MTA processing\",\"$schem"
    "a\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"zone_count"
    "\":{\"type\":\"integer\",\"description\":\"Maximum number of MTA zones.\",\"maxi"
    "mum\":255,\"minimum\":0},\"zone_width\":{\"type\":\"number\",\"description\":\"Wid"
    "th of a MTA zone in meter.\",\"minimum\":0},\"modulation_depth\":{\"type\":\"n"
    "umber\",\"description\":\"Depth of pulse position modulation in "
    "meter.\",\"minimum\":0}},\"title\":\"MTA Settings\"}"
    ,
    /* example: */
    "{\"zone_count\":23,\"zone_width\":149.896225,\"modulation_depth\":9.368514}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":"
    "\"Delta between table entries [m], first entry is at range = 0 "
    "m\"},\"content\":{\"type\":\"array\",\"description\":\"Correction value [m] to "
    "be added to the raw range\",\"minItems\":1,\"maxItems\":2000,\"items\":{\"type"
    "\":\"number\"}}},\"title\":\"Near Range Correction "
    "Table\",\"description\":\"Lookup table for range correction based on raw r"
    "ange\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":["
    "\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"range_sigma\":{\"type\":\"array\",\"descript"
    "ion\":\"Sigma range [m]\",\"items\":{\"type\":\"number\"}},\"amplitude\":{\"type\":"
    "\"array\",\"description\":\"Amplitude [dB]\",\"items\":{\"type\":\"number\"}},\"amp"
    "litude_sigma\":{\"type\":\"array\",\"description\":\"Sigma amplitude "
    "[dB]\",\"items\":{\"type\":\"number\"}}},\"title\":\"Noise "
    "Estimates\",\"description\":\"Standard deviation for range and amplitude "
    "as a function of amplitude\",\"$schema\":\"http://json-schema.org/draft-04"
    "/schema#\",\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"]}"
    ,
    /* example: */
    "{\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.018,"
    "0.016,0.014],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0"
    "],\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0."
    "432,0.39,0.354]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"range_maximum\":{\"type\":\"number\",\"descr"
    "iption\":\"Maximum range "
    "[m]\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "amplitude [dB]\",\"minimum\":0},\"range_minimum\":{\"type\":\"number\",\"descrip"
    "tion\":\"Minimum range [m]\"}},\"title\":\"Notch "
    "Filter\",\"description\":\"Notch filter parameters for window glass echoes"
    "\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"ran"
    "ge_minimum\",\"range_maximum\",\"amplitude_maximum\"]}"
    ,
    /* example: */
    "{\"range_maximum\":0.2,\"amplitude_maximum\":18.0,\"range_minimum\":-0.5}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"size\":{\"$ref\":\"#/definitions/pixel_siz"
    "e\",\"description\":\"Size of pixels in file coordinate system.\"},\"size_ll"
    "cs\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of pixels "
    "in a locally levelled cartesian coordinate system (xy). This is only "
    "used for pixels based on a map projection.\"}},\"title\":\"Pixel Informati"
    "on\",\"definitions\":{\"pixel_size\":{\"type\":\"array\",\"description\":\"Size of"
    " pixels.\",\"minItems\":2,\"maxItems\":2,\"items\":{\"type\":\"number\",\"descript"
    "ion\":\"Length of pixel edge [m].\",\"minimum\":0}}},\"description\":\"Details"
    " about the pixels contained in the file\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"required\":[\"size\"]}"
    ,
    /* example: */
    "{\"size\":[0.5971642834779395,0.5971642834779395],\"size_llcs\":[0.5156575"
    "252891171,0.5130835356683303]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"plane_patch_file_two\":{\"$ref\":\"#/defin"
    "itions/file_reference\",\"description\":\"Reference to the plane patch "
    "file two\"},\"plane_patch_file_one\":{\"$ref\":\"#/definitions/file_referenc"
    "e\",\"description\":\"Reference to the plane patch file "
    "one\"}},\"title\":\"Plane Patch Matching\",\"definitions\":{\"file_reference\":"
    "{\"type\":\"object\",\"description\":\"Reference to a plane patch file\",\"requ"
    "ired\":[\"file_uuid\",\"file_path\"],\"properties\":{\"file_path\":{\"type\":\"str"
    "ing\",\"description\":\"Path of the plane patch file relative to the match"
    " file\"},\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch file's"
    " Universally Unique Identifier (RFC 4122)\"}}}},\"description\":\"Details "
    "about the plane patch matching process\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"required\":[\"plane_patch_file_one\",\"plane_patch_"
    "file_two\"]}"
    ,
    /* example: */
    "{\"plane_patch_file_two\":{\"file_path\":\"project.ptch\",\"file_uuid\":\"fa47d"
    "509-a64e-49ce-8b14-ff3130fbefa9\"},\"plane_patch_file_one\":{\"file_path\":"
    "\"Record009_Line001/191025_121410_Scanner_1.ptch\",\"file_uuid\":\"810f5d57"
    "-eccf-49ed-b07a-0cdd109b4213\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Statistics about plane patches found "
    "by plane patch extractor\",\"$schema\":\"http://json-schema.org/draft-04/s"
    "chema#\",\"properties\":{\"total_horizontal_area\":{\"type\":\"number\",\"descri"
    "ption\":\"sum of all plane patch areas projected to horizontal plane "
    "[m\\u00b2]\"},\"total_area\":{\"type\":\"number\",\"description\":\"sum of all "
    "plane patch areas [m\\u00b2]\"}},\"title\":\"Plane Patch Statistics\"}"
    ,
    /* example: */
    "{\"total_horizontal_area\":13954.601,\"total_area\":14007.965}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"settings\":{\"type\":\"object\",\"descriptio"
    "n\":\"Classification settings, details see documentation of rdbplanes\",\""
    "oneOf\":[{\"$ref\":\"#/definitions/method-1\"},{\"$ref\":\"#/definitions/metho"
    "d-2\"}]},\"classes\":{\"type\":\"object\",\"description\":\"Class definition tab"
    "le\",\"patternProperties\":{\"^[0-9]+$\":{\"type\":\"string\",\"description\":\"on"
    "e field per class, field name is class number, field value is class "
    "name\"}},\"additionalProperties\":false}},\"title\":\"Plane Slope Class Info"
    "\",\"definitions\":{\"method-2\":{\"type\":\"object\",\"description\":\"Classifica"
    "tion method 2\",\"required\":[\"plane_classification_method\",\"sloping_plan"
    "e_classes_minimum_angle\",\"sloping_plane_classes_maximum_angle\"],\"prope"
    "rties\":{\"sloping_plane_classes_maximum_angle\":{\"type\":\"number\",\"descri"
    "ption\":\"maximum inclination angle of sloping plane patches [deg]\",\"max"
    "imum\":360.0,\"minimum\":-360.0},\"plane_classification_method\":{\"type\":\"i"
    "nteger\",\"description\":\"method ID (=2)\",\"maximum\":2,\"minimum\":2},\"slopi"
    "ng_plane_classes_minimum_angle\":{\"type\":\"number\",\"description\":\"minimu"
    "m inclination angle of sloping plane patches [deg]\",\"maximum\":360.0,\"m"
    "inimum\":-360.0}}},\"method-1\":{\"type\":\"object\",\"description\":\"Classific"
    "ation method 1\",\"required\":[\"plane_classification_method\",\"maximum_inc"
    "lination_angle_horizontal\"],\"properties\":{\"maximum_inclination_angle_h"
    "orizontal\":{\"type\":\"number\",\"description\":\"maximum inclination angle "
    "of horizontal plane patches [deg]\",\"maximum\":360.0,\"minimum\":-360.0},\""
    "plane_classification_method\":{\"type\":\"integer\",\"description\":\"method "
    "ID (=1)\",\"maximum\":1,\"minimum\":1}}}},\"description\":\"Settings and "
    "classes for plane slope classification\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"required\":[\"settings\",\"classes\"]}"
    ,
    /* example: */
    "{\"settings\":{\"sloping_plane_classes_maximum_angle\":70.0,\"plane_classif"
    "ication_method\":2,\"sloping_plane_classes_minimum_angle\":10.0},\"classes"
    "\":{\"10\":\"sloping, pointing down and east\",\"14\":\"horizontal, pointing "
    "down\",\"7\":\"vertical, pointing south\",\"9\":\"vertical, pointing "
    "west\",\"2\":\"sloping, pointing up and east\",\"8\":\"vertical, pointing "
    "north\",\"6\":\"vertical, pointing east\",\"3\":\"sloping, pointing up and "
    "south\",\"5\":\"sloping, pointing up and west\",\"13\":\"sloping, pointing "
    "down and west\",\"11\":\"sloping, pointing down and south\",\"4\":\"sloping, "
    "pointing up and north\",\"1\":\"horizontal, pointing up\",\"12\":\"sloping, "
    "pointing down and north\"}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"descript"
    "ion\":\"Each field of the object represents a point attribute group and "
    "holds a list of point attributes, where the field name is the group "
    "name.\",\"minItems\":1,\"items\":{\"type\":\"string\",\"description\":\"Point "
    "attribute full name or name pattern (perl regular expression "
    "syntax)\"}}},\"title\":\"Point Attribute "
    "Groups\",\"additionalProperties\":false,\"description\":\"Grouping and "
    "sorting of point attributes for visualization "
    "purposes\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"Coordinates/Vectors\":[\"riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl"
    ".phi\"],\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Primary"
    " Attributes\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.deviation\"]"
    ",\"Time\":[\"riegl.timestamp\"],\"Other "
    "Attributes\":[\"riegl.selected\",\"riegl.visible\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about point cloud files\",\"$sch"
    "ema\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"field_of"
    "_application\":{\"type\":\"string\",\"description\":\"Field of application\",\"e"
    "num\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS\",\"ILS\"]},\"com"
    "ments\":{\"type\":\"string\",\"description\":\"Comments\"},\"project\":{\"type\":\"s"
    "tring\",\"description\":\"Project name\"}},\"title\":\"Point Cloud "
    "Information\"}"
    ,
    /* example: */
    "{\"field_of_application\":\"ALS\",\"comments\":\"Line 3\",\"project\":\"Campaign "
    "4\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"barometric_height_amsl\":{\"type\":\"numbe"
    "r\",\"description\":\"Altitude determined based on the atmospheric "
    "pressure according to the standard atmosphere laws "
    "[m].\"},\"orientation\":{\"type\":\"object\",\"description\":\"Orientation "
    "values and orientation accuracies, measured with IMU or inclination se"
    "nsors.\",\"required\":[\"roll\",\"pitch\",\"yaw\",\"roll_accuracy\",\"pitch_accura"
    "cy\",\"yaw_accuracy\"],\"properties\":{\"roll\":{\"type\":\"number\",\"description"
    "\":\"Roll angle about scanner X-axis [deg]\",\"maximum\":360,\"minimum\":-360"
    "},\"roll_accuracy\":{\"type\":\"number\",\"description\":\"Roll angle accuracy "
    "[deg]\",\"exclusiveMinimum\":true,\"minimum\":0},\"yaw\":{\"type\":\"number\",\"de"
    "scription\":\"Yaw angle about scanner Z-axis [deg]\",\"maximum\":360,\"minim"
    "um\":-360},\"yaw_accuracy\":{\"type\":\"number\",\"description\":\"Yaw angle "
    "accuracy [deg]\",\"exclusiveMinimum\":true,\"minimum\":0},\"pitch\":{\"type\":\""
    "number\",\"description\":\"Pitch angle about scanner Y-axis [deg]\",\"maximu"
    "m\":360,\"minimum\":-360},\"pitch_accuracy\":{\"type\":\"number\",\"description\""
    ":\"Pitch angle accuracy [deg]\",\"exclusiveMinimum\":true,\"minimum\":0}}},\""
    "position\":{\"type\":\"object\",\"description\":\"Position coordinates and "
    "position accuracy values as measured by GNSS in the specified "
    "Coordinate Reference System (CRS)\",\"required\":[\"coordinate_1\",\"coordin"
    "ate_2\",\"coordinate_3\",\"horizontal_accuracy\",\"vertical_accuracy\",\"crs\"]"
    ",\"properties\":{\"vertical_accuracy\":{\"type\":\"number\",\"description\":\"Ver"
    "tical accuracy [m]\",\"exclusiveMinimum\":true,\"minimum\":0},\"crs\":{\"type\""
    ":\"object\",\"description\":\"Global Coordinate Reference System\",\"required"
    "\":[\"epsg\"],\"properties\":{\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-"
    "Known Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.or"
    "g/standards/wkt-crs)\"},\"epsg\":{\"type\":\"integer\",\"description\":\"EPSG co"
    "de\",\"minimum\":0}}},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coor"
    "dinate 3 as defined by axis 3 of the specified CRS (e.g., Z, "
    "Altitude)\"},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinate "
    "2 as defined by axis 2 of the specified CRS (e.g., Y, Longitude)\"},\"ho"
    "rizontal_accuracy\":{\"type\":\"number\",\"description\":\"Horizontal accuracy"
    " [m]\",\"exclusiveMinimum\":true,\"minimum\":0},\"coordinate_1\":{\"type\":\"num"
    "ber\",\"description\":\"Coordinate 1 as defined by axis 1 of the specified"
    " CRS (e.g., X, Latitude)\"}}}},\"title\":\"Pose "
    "Estimation\",\"description\":\"Estimated position and orientation "
    "information as measured by GNSS, IMU or inclination sensors\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"orientation\"]}"
    ,
    /* example: */
    "{\"barometric_height_amsl\":386.7457796227932,\"orientation\":{\"roll\":3.14"
    "743073066123,\"roll_accuracy\":0.009433783936875745,\"yaw\":101.8729363029"
    "2045,\"yaw_accuracy\":1.0094337839368757,\"pitch\":1.509153024827064,\"pitc"
    "h_accuracy\":0.009433783936875745},\"position\":{\"vertical_accuracy\":1.33"
    "14999341964722,\"crs\":{\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS"
    "84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\"
    "\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000"
    "000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.017453292519"
    "94329547,AUTHORITY[\\\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\"
    "\"Longitude\\\",EAST],AUTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\",\"epsg\":4979},\"coordi"
    "nate_3\":362.7124938964844,\"coordinate_2\":15.645033406,\"horizontal_accu"
    "racy\":0.810699999332428,\"coordinate_1\":48.655799473}}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"accelerometer\":{\"type\":\"object\",\"descr"
    "iption\":\"Accelerometer details\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\""
    "z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"properties\":{\"offs"
    "et\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be "
    "subtracted from raw measurement "
    "values\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\",\"exclusiveMinimum\":true,\""
    "minimum\":0},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sen"
    "sitive Y axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{"
    "\"$ref\":\"#/definitions/vector\",\"description\":\"Relative nonlinearity, di"
    "mensionless\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"S"
    "ensitive X axis of sensor at frame angle = "
    "0\"}}},\"gyroscope\":{\"type\":\"object\",\"description\":\"Gyroscope details\",\""
    "required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relati"
    "ve_nonlinearity\"],\"properties\":{\"offset\":{\"$ref\":\"#/definitions/vector"
    "\",\"description\":\"Value to be subtracted from raw measurement "
    "values\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor"
    " origin in SOCS [m] at frame angle = "
    "0\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Z"
    " axis of sensor at frame angle = "
    "0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in rad/s\",\"exclusiveMinimum\":true,\"minimum\":"
    "0},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y "
    "axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\"#"
    "/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionle"
    "ss\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive "
    "X axis of sensor at frame angle = "
    "0\"}}},\"magnetic_field_sensor\":{\"type\":\"object\",\"description\":\"Magnetic"
    " Field Sensor details\",\"required\":[\"unit\",\"x_axis\",\"y_axis\",\"z_axis\",\""
    "offset\",\"fixed\",\"relative_nonlinearity\"],\"properties\":{\"offset\":{\"$ref"
    "\":\"#/definitions/vector\",\"description\":\"Value to be subtracted from "
    "raw measurement values\"},\"fixed\":{\"$ref\":\"#/definitions/vector\",\"descr"
    "iption\":\"Distortion of magnetic field caused by non-rotating scanner p"
    "art\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Z axis of sensor at frame angle = "
    "0\"},\"unit\":{\"type\":\"number\",\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in nT\",\"exclusiveMinimum\":true,\"minimum\":0},"
    "\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive Y "
    "axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\"#"
    "/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionle"
    "ss\"},\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive "
    "X axis of sensor at frame angle = 0\"}}}},\"title\":\"Pose Sensors\",\"defin"
    "itions\":{\"vector\":{\"type\":\"array\",\"minItems\":3,\"maxItems\":3,\"items\":{\""
    "type\":\"number\",\"description\":\"Index 0=X, 1=Y, 2=Z "
    "component\"}}},\"description\":\"Details on position and orientation senso"
    "rs\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"g"
    "yroscope\",\"accelerometer\",\"magnetic_field_sensor\"]}"
    ,
    /* example: */
    "{\"accelerometer\":{\"offset\":[-733.3636474609375,58.969032287597656,1060"
    ".2550048828125],\"origin\":[0.026900000870227814,-0.03999999910593033,-0"
    ".08950000256299973],\"z_axis\":[1.639882206916809,15166.744140625,-116.9"
    "9742889404297],\"unit\":6.666666740784422e-05,\"y_axis\":[-7.0272889137268"
    "07,-44.12333679199219,14952.3701171875],\"relative_nonlinearity\":[0.0,0"
    ".0,0.0],\"x_axis\":[-15008.123046875,56.956390380859375,-60.517566680908"
    "2]},\"gyroscope\":{\"offset\":[-50.92609786987305,146.15643310546875,62.43"
    "27278137207],\"origin\":[0.026900000870227814,-0.03999999910593033,-0.08"
    "950000256299973],\"z_axis\":[0.555869996547699,119.22135162353516,0.4675"
    "85027217865],\"unit\":0.00014544410805683583,\"y_axis\":[-0.44076591730117"
    "8,-0.7897399663925171,119.5894775390625],\"relative_nonlinearity\":[2.88"
    "8176311444113e-07,1.06274164579645e-07,-1.7186295080634935e-39],\"x_axi"
    "s\":[-121.195556640625,0.8219714164733887,0.2313031703233719]},\"magneti"
    "c_field_sensor\":{\"offset\":[-23812.052734375,5606.57666015625,2493.2812"
    "5],\"fixed\":[-1576.010498046875,1596.081787109375,0.0],\"z_axis\":[0.0004"
    "1987866279669106,7.876977906562388e-05,0.011407104320824146],\"unit\":91"
    ".74311828613281,\"y_axis\":[0.00027888521435670555,-0.011427424848079681"
    ",-5.204829722060822e-05],\"relative_nonlinearity\":[0.0,0.0,0.0],\"x_axis"
    "\":[-0.011162743903696537,-2.315962774446234e-05,0.00016818844596855342"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"num_mod_ampl\":{\"type\":\"integer\",\"descr"
    "iption\":\"Number of different modulation amplitudes (2: binary modulati"
    "on)\",\"maximum\":255,\"minimum\":0},\"phase_step\":{\"type\":\"integer\",\"descri"
    "ption\":\"Step width in phase of modulation code from line to line\",\"max"
    "imum\":255,\"minimum\":0},\"length\":{\"type\":\"integer\",\"description\":\"Lengt"
    "h of code\",\"maximum\":255,\"minimum\":0},\"pulse_interval\":{\"type\":\"array\""
    ",\"description\":\"Explicit table of the pulse position modulation used "
    "for MTA resolution. Table gives times between successive laser pulses "
    "in seconds.\",\"items\":{\"type\":\"number\",\"minimum\":0}},\"code_phase_mode\":"
    "{\"type\":\"integer\",\"description\":\"0: no synchronization, 1: toggle "
    "between 2 phases, 2: increment with "
    "phase_increment\",\"maximum\":255,\"minimum\":0}},\"title\":\"Pulse Position "
    "Modulation\",\"description\":\"Laser pulse position modulation used for "
    "MTA resolution\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"r"
    "equired\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"]}"
    ,
    /* example: */
    "{\"num_mod_ampl\":2,\"phase_step\":5,\"length\":31,\"pulse_interval\":[2.75937"
    "5e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06"
    ",2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.75"
    "9375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e"
    "-06,2.821875e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2"
    ".821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.7593"
    "75e-06,2.821875e-06,2.759375e-06,2.821875e-06],\"code_phase_mode\":2}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"maximum\":{\"type\":\"number\",\"description"
    "\":\"Maximum value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"average\":{\"type\":\"number\",\"description\":\"Average "
    "value\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"}},\"title\":\"Range Statistics\",\"description\":\"Statistics about "
    "target distance wrt. SOCS origin\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"]}"
    ,
    /* example: */
    "{\"maximum\":574.35,\"std_dev\":24.349,\"average\":15.49738,\"minimum\":0.919}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"t\":{\"type\":\"object\",\"patternProperties"
    "\":{\"^[0-9]+$\":{\"description\":\"one field per channel, field name is "
    "channel index\",\"$ref\":\"#/definitions/fp\"}},\"additionalProperties\":fals"
    "e},\"a\":{\"type\":\"array\",\"description\":\"Amplitude [dB]\",\"minItems\":1,\"ma"
    "xItems\":256,\"items\":{\"type\":\"number\"}},\"sr\":{\"type\":\"number\",\"exclusiv"
    "eMinimum\":true,\"minimum\":0,\"description\":\"Sample rate "
    "[Hz]\"},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECATED, use "
    "'riegl.exponential_decomposition' instead\"},\"si\":{\"type\":\"number\",\"max"
    "imum\":255,\"minimum\":0,\"description\":\"Start index (hw_start)\"},\"ns\":{\"t"
    "ype\":\"integer\",\"maximum\":4095,\"minimum\":0,\"description\":\"Number of "
    "samples\"},\"tbl\":{\"type\":\"array\",\"description\":\"various internal data\","
    "\"minItems\":1,\"items\":{\"$ref\":\"#/definitions/fp_table\"}},\"nt\":{\"type\":\""
    "integer\",\"maximum\":255,\"minimum\":0,\"description\":\"Number of traces\"},\""
    "mw\":{\"type\":\"number\",\"maximum\":4095,\"exclusiveMinimum\":true,\"minimum\":"
    "0,\"description\":\"Maximum weight\"}},\"title\":\"Receiver Internals\",\"defin"
    "itions\":{\"fp_table\":{\"type\":\"object\",\"properties\":{\"ch\":{\"type\":\"integ"
    "er\",\"description\":\"channel number\",\"min\":0,\"max\":255},\"ny\":{\"type\":\"in"
    "teger\",\"description\":\"number of y entries\",\"min\":1,\"max\":2048},\"nx\":{\""
    "type\":\"integer\",\"description\":\"number of x entries\",\"min\":1,\"max\":2048"
    "},\"tv\":{\"type\":\"array\",\"minItems\":1,\"maxItems\":2048,\"items\":{\"oneOf\":["
    "{\"$ref\":\"#/definitions/fp_table_row\"},{\"type\":\"number\"}]}},\"tc\":{\"type"
    "\":\"integer\",\"description\":\"table data type "
    "code\",\"min\":0,\"max\":255}},\"desription\":\"scanner internal data\",\"requir"
    "ed\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"]},\"fp\":{\"type\":\"object\",\"description\":\"F"
    "ingerprint values\",\"required\":[\"s\",\"w\"],\"properties\":{\"s\":{\"type\":\"arr"
    "ay\",\"minItems\":1,\"maxItems\":256,\"items\":{\"type\":\"array\",\"minItems\":1,\""
    "maxItems\":4096,\"items\":{\"type\":\"number\"}}},\"w\":{\"type\":\"array\",\"minIte"
    "ms\":1,\"maxItems\":256,\"items\":{\"type\":\"array\",\"minItems\":5,\"maxItems\":5"
    ",\"items\":{\"type\":\"number\"}}}}},\"fp_table_row\":{\"type\":\"array\",\"minItem"
    "s\":1,\"maxItems\":2048,\"items\":{\"type\":\"number\"}}},\"description\":\"Receiv"
    "er Internals\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"t\":{\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134,31],[78,8"
    "6,126,134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,134"
    ",31],[78,86,126,134,31]]}},\"a\":[-1.55],\"sr\":7959997000.0,\"si\":48,\"ns\":"
    "400,\"tbl\":[{\"ch\":0,\"ny\":2,\"nx\":5,\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5."
    "5]],\"tc\":1}],\"nt\":128,\"mw\":31}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":"
    "\"Delta between table entries [m], first entry is at range = 0 "
    "m\"},\"content\":{\"type\":\"array\",\"description\":\"Correction value [dB] to "
    "be added to the amplitude\",\"minItems\":1,\"maxItems\":2000,\"items\":{\"type"
    "\":\"number\"}}},\"title\":\"Reflectance Calculation "
    "Table\",\"description\":\"Lookup table for reflectance calculation based "
    "on amplitude and range\",\"$schema\":\"http://json-schema.org/draft-04/sch"
    "ema#\",\"required\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"ranges_m\":{\"type\":\"array\",\"description"
    "\":\"Range [m]\",\"items\":{\"type\":\"number\"}},\"line_angles_deg\":{\"type\":\"ar"
    "ray\",\"description\":\"Angle [deg]\",\"items\":{\"type\":\"number\"}},\"reflectan"
    "ce_correction_db\":{\"type\":\"array\",\"description\":\"Near range "
    "reflectance correction in dB as a function of range over "
    "angle\",\"items\":{\"type\":\"array\",\"description\":\"rows (each array "
    "corresponds to a "
    "range)\",\"items\":{\"type\":\"number\",\"description\":\"columns (each value "
    "corresponds to an angle)\"}}}},\"title\":\"Near-range reflectance "
    "correction\",\"description\":\"Range-dependent and scan-angle-dependent "
    "correction of reflectance reading\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"required\":[\"ranges_m\",\"line_angles_deg\",\"reflectance"
    "_correction_db\"]}"
    ,
    /* example: */
    "{\"ranges_m\":[0.0,1.0,2.0,3.0],\"line_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2"
    ".0,2.5,3.0,3.5,4.0],\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,"
    "0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0."
    "8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,"
    "0.1,0.05,0.01]]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"segments\":{\"type\":\"object\",\"description\":\"Segmented "
    "Line Scan Pattern\",\"required\":[\"list\"],\"properties\":{\"program\":{\"$ref\""
    ":\"#/definitions/program\"},\"list\":{\"type\":\"array\",\"items\":{\"type\":\"obje"
    "ct\",\"description\":\"Line Scan Segment\",\"required\":[\"start\",\"stop\",\"incr"
    "ement\"],\"properties\":{\"start\":{\"type\":\"number\",\"description\":\"Start "
    "angle in SOCS [deg]\",\"maximum\":360.0,\"minimum\":0.0},\"stop\":{\"type\":\"nu"
    "mber\",\"description\":\"Stop angle in SOCS [deg]\",\"maximum\":720.0,\"minimu"
    "m\":0.0},\"increment\":{\"type\":\"number\",\"description\":\"Increment of angle"
    " in SOCS [deg]\",\"maximum\":90.0,\"minimum\":0.0}}}}}},\"line\":{\"type\":\"obj"
    "ect\",\"description\":\"Line Scan Pattern\",\"required\":[\"start\",\"stop\",\"inc"
    "rement\"],\"properties\":{\"program\":{\"$ref\":\"#/definitions/program\"},\"sta"
    "rt\":{\"type\":\"number\",\"description\":\"Start angle in SOCS [deg]\",\"maximu"
    "m\":360.0,\"minimum\":0.0},\"stop\":{\"type\":\"number\",\"description\":\"Stop "
    "angle in SOCS [deg]\",\"maximum\":720.0,\"minimum\":0.0},\"increment\":{\"type"
    "\":\"number\",\"description\":\"Increment of angle in SOCS [deg]\",\"maximum\":"
    "90.0,\"minimum\":0.0}}},\"rectangular\":{\"type\":\"object\",\"description\":\"Re"
    "ctangular Field Of View Scan Pattern\",\"required\":[\"phi_start\",\"phi_sto"
    "p\",\"phi_increment\",\"theta_start\",\"theta_stop\",\"theta_increment\"],\"prop"
    "erties\":{\"theta_stop\":{\"type\":\"number\",\"description\":\"Stop theta angle"
    " in SOCS [deg]\",\"maximum\":180.0,\"minimum\":0.0},\"theta_increment\":{\"typ"
    "e\":\"number\",\"description\":\"Increment of theta angle in SOCS [deg]\",\"ma"
    "ximum\":90.0,\"minimum\":0.0},\"phi_start\":{\"type\":\"number\",\"description\":"
    "\"Start phi angle in SOCS [deg]\",\"maximum\":360.0,\"minimum\":0.0},\"phi_st"
    "op\":{\"type\":\"number\",\"description\":\"Stop phi angle in SOCS [deg]\",\"max"
    "imum\":720.0,\"minimum\":0.0},\"phi_increment\":{\"type\":\"number\",\"descripti"
    "on\":\"Increment of phi angle in SOCS [deg]\",\"maximum\":90.0,\"minimum\":0."
    "0},\"theta_start\":{\"type\":\"number\",\"description\":\"Start theta angle in "
    "SOCS [deg]\",\"maximum\":180.0,\"minimum\":0.0},\"program\":{\"$ref\":\"#/defini"
    "tions/program\"}}}},\"description\":\"Scan pattern description\",\"$schema\":"
    "\"http://json-schema.org/draft-04/schema#\",\"definitions\":{\"program\":{\"t"
    "ype\":\"object\",\"description\":\"Measurement program\",\"required\":[\"name\"],"
    "\"properties\":{\"laser_prr\":{\"type\":\"number\",\"description\":\"Laser Pulse "
    "Repetition Rate [Hz]\",\"exclusiveMinimum\":false,\"minimum\":0},\"name\":{\"t"
    "ype\":\"string\",\"description\":\"Name of measurement "
    "program\"}}}},\"title\":\"Scan Pattern\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"theta_stop\":130.0,\"theta_increment\":0.04,\"phi_start\":"
    "45.0,\"phi_stop\":270.0,\"phi_increment\":0.04,\"theta_start\":30.0,\"program"
    "\":{\"laser_prr\":100000.0,\"name\":\"High Speed\"}}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about laser shot files\",\"$sche"
    "ma\":\"http://json-schema.org/draft-04/schema#\",\"properties\":{\"shot_file"
    "\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"descrip"
    "tion\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"title\":\"Shot Information\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"activated\":{\"type\":\"boolean\",\"descript"
    "ion\":\"Apply ('true') or ignore ('false') all "
    "filters\"},\"filters\":{\"type\":\"array\",\"description\":\"List of point "
    "filters\",\"items\":{\"type\":\"object\",\"description\":\"Point filter definiti"
    "on\",\"required\":[\"activated\",\"title\",\"description\",\"filter\"],\"propertie"
    "s\":{\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') or "
    "ignore ('false') this "
    "filter\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a "
    "tooltip)\"},\"filter\":{\"type\":\"string\",\"description\":\"The RDB filter "
    "string to apply (e.g. when reading points or index), details see "
    "documentation of function "
    "select()\"},\"title\":{\"type\":\"string\",\"description\":\"A short filter "
    "title (e.g. for display in a selection list)\"}}}}},\"title\":\"Stored "
    "filters\",\"description\":\"Point filters applied in addition to the "
    "application-defined filters\",\"$schema\":\"http://json-schema.org/draft-0"
    "4/schema#\",\"required\":[\"activated\",\"filters\"]}"
    ,
    /* example: */
    "{\"activated\":true,\"filters\":[{\"activated\":false,\"description\":\"Ignore "
    "points with uncertain MTA zone "
    "assignment\",\"filter\":\"riegl.mta_uncertain_point == 0\",\"title\":\"Ignore "
    "uncertain points from MTA "
    "resolution\"},{\"activated\":false,\"description\":\"Ignore points with an "
    "echo signal amplitude below the dynamic "
    "trigger\",\"filter\":\"riegl.dyntrig_uncertain_point == 0\",\"title\":\"Ignore"
    " points below dynamic trigger "
    "level\"},{\"activated\":false,\"description\":\"Ignore points that are "
    "outside the outer AABB in "
    "BOCS\",\"filter\":\"riegl.point_outside_aabb_bocs == 0\",\"title\":\"Ignore "
    "points outside outer AABB\"},{\"activated\":false,\"description\":\"Ignore "
    "points that are inside the inner AABB in "
    "BOCS\",\"filter\":\"riegl.point_inside_aabb_bocs == 0\",\"title\":\"Ignore "
    "points inside inner AABB\"}]}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"system\":{\"type\":\"object\",\"description\""
    ":\"The actual system description, details see documentation of RIEGL "
    "System Description\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date "
    "and time of creation (e.g. 2019-06-19T13:32:10+02:00)\"},\"version\":{\"ty"
    "pe\":\"string\",\"description\":\"Document format "
    "version\"},\"$class\":{\"type\":\"string\",\"description\":\"Object class name\","
    "\"enum\":[\"Document\"]},\"author\":{\"type\":\"string\",\"description\":\"Name of "
    "the author that created the document\"}},\"title\":\"System "
    "Description\",\"description\":\"Details of major system components like "
    "lidar sensors, cameras and navigation devices\",\"$schema\":\"http://json-"
    "schema.org/draft-04/schema#\",\"required\":[\"$class\",\"version\",\"author\",\""
    "timestamp\",\"system\"]}"
    ,
    /* example: */
    "{\"system\":{\"details\":\"see documentation of RIEGL System Description\"},"
    "\"timestamp\":\"2022-09-30T11:56:26+00:00\",\"version\":\"1.2.1\",\"$class\":\"Do"
    "cument\",\"author\":\"RIEGL LMS GmbH, Austria\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"InGaAs_Si_Difference\":{\"$ref\":\"#/defin"
    "itions/conversion_table\",\"description\":\"Conversion table for InGaAs - "
    "Si difference\"},\"Si\":{\"$ref\":\"#/definitions/conversion_table\",\"descrip"
    "tion\":\"Conversion table for Si channel\"},\"InGaAs\":{\"$ref\":\"#/definitio"
    "ns/conversion_table\",\"description\":\"Conversion table for InGaAs "
    "channel\"}},\"title\":\"Temperature Calculation Table\",\"definitions\":{\"con"
    "version_table\":{\"type\":\"object\",\"properties\":{\"temperature\":{\"type\":\"a"
    "rray\",\"description\":\"Temperature [\\u00b0C]\",\"items\":{\"type\":\"number\"}}"
    ",\"value\":{\"type\":\"array\",\"description\":\"LSB [1]\",\"items\":{\"type\":\"numb"
    "er\"}}},\"required\":[\"value\",\"temperature\"]}},\"description\":\"Conversion "
    "of background radiation raw values to temperatures in "
    "\\u00b0C\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"temperature\":[1749.977111117893,1749.9771111"
    "17893,1749.977111117893,1749.977111117893,1749.977111117893,1749.97711"
    "1117893,1744.7813348796044,1681.9971312601092,1622.3944822534868],\"val"
    "ue\":[1000.0,1100.090029602954,1200.04425183874,1300.1342814416948,1400"
    ".0885036774805,1500.0427259132668,1600.1327555162209,1700.086977752006"
    "5,1800.0411999877924]},\"Si\":{\"temperature\":[546.300048828125,548.81640"
    "51212026,551.3143938500972,554.0144257850053,556.604252334815,559.2124"
    "464488079,561.8022729986177,564.4104671126105,567.0002936624203],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]},\"InGaAs\":{\"temperature\":[307.22196722535614,309.1153478"
    "247277,311.1188086915047,313.10025350480055,315.2137946389828,317.2172"
    "555057597,319.2207163725366,321.2021611858325,323.3157023200148],\"valu"
    "e\":[0.0,64.00097659230323,128.0019531846065,192.0029297769097,256.0039"
    "063692129,320.00488296151616,384.0058595538194,448.0068361461226,512.0"
    "078127384259]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"system\":{\"type\":\"string\",\"description\""
    ":\"Time system (time standard)\",\"enum\":[\"unknown\",\"UTC\",\"GPS\"]},\"epoch\""
    ":{\"type\":\"string\",\"description\":\"Date and time of timestamp '0' as "
    "proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00).\"},\"source\":{\"ty"
    "pe\":\"string\",\"description\":\"Timestamp "
    "source\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"]}},\"title\":\"Time "
    "Base\",\"description\":\"Base of timestamps (epoch)\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"required\":[\"epoch\",\"source\"]}"
    ,
    /* example: */
    "{\"system\":\"UTC\",\"epoch\":\"2015-10-27T00:00:00+00:00\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"device\":{\"type\":\"string\",\"description\""
    ":\"Navigation device, e.g. name/type/serial\"},\"navigation_frame\":{\"type"
    "\":\"string\",\"description\":\"Navigation frame (NED: North-East-Down, ENU:"
    " East-North-Up)\",\"enum\":[\"unknown\",\"NED\",\"ENU\"]},\"location\":{\"type\":\"s"
    "tring\",\"description\":\"Project location, e.g. city/state/country\"},\"sof"
    "tware\":{\"type\":\"string\",\"description\":\"Software that calculated the "
    "trajectory (this may be the same or different software than the one "
    "that created the "
    "file)\"},\"time_interval\":{\"type\":\"object\",\"description\":\"Time interval "
    "statistics\",\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],\"prop"
    "erties\":{\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time "
    "interval [s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation of intervals "
    "[s]\"},\"average\":{\"type\":\"number\",\"description\":\"Average time interval "
    "[s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time interval "
    "[s]\"}}},\"field_of_application\":{\"type\":\"string\",\"description\":\"Field "
    "of application\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\","
    "\"BLS\",\"ILS\"]},\"company\":{\"type\":\"string\",\"description\":\"Company "
    "name\"},\"project\":{\"type\":\"string\",\"description\":\"Project "
    "name\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings used to "
    "calculate the trajectory (descriptive text)\"}},\"title\":\"Trajectory "
    "Information\",\"description\":\"Details about position+orientation files\","
    "\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"time_"
    "interval\",\"navigation_frame\"]}"
    ,
    /* example: */
    "{\"device\":\"IMU Model 12/1, Serial# 12345\",\"navigation_frame\":\"NED\",\"lo"
    "cation\":\"Horn\",\"software\":\"Navigation Software XYZ\",\"time_interval\":{\""
    "maximum\":0.005004883,\"std_dev\":5.51e-07,\"average\":0.00500053,\"minimum\""
    ":0.00500032},\"field_of_application\":\"MLS\",\"company\":\"RIEGL "
    "LMS\",\"project\":\"Campaign 3\",\"settings\":\"default\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"ext_subdivider\":{\"type\":\"integer\",\"des"
    "cription\":\"reduces the frequency, default 1\",\"minimum\":0},\"in_max_dura"
    "tion\":{\"type\":\"integer\",\"description\":\"stops measurement of pulse "
    "duration of input signal [0.1 msec]\",\"minimum\":0},\"output_descr\":{\"typ"
    "e\":\"string\",\"description\":\"descriptive "
    "string\"},\"ext_channel\":{\"type\":\"integer\",\"description\":\"ID of channel "
    "used as external trigger input, 32 indicates none\",\"minimum\":0},\"dmi_d"
    "ist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, distance per tick, "
    "just informative "
    "[m]\"},\"ext_delay\":{\"type\":\"integer\",\"description\":\"external trigger, "
    "time delay [0.1 msec]\",\"minimum\":0},\"in_min_duration\":{\"type\":\"integer"
    "\",\"description\":\"input signals with smaller pulse durations are "
    "ignored [0.1 msec]\",\"minimum\":0},\"out_duration\":{\"type\":\"integer\",\"des"
    "cription\":\"output pulse duration [0.1 msec]\",\"minimum\":0},\"out_num_pul"
    "ses\":{\"type\":\"integer\",\"description\":\"number of output pulses to be "
    "generated, 0 .. "
    "infinite\",\"minimum\":0},\"channel\":{\"type\":\"integer\",\"description\":\"ID "
    "of input/output "
    "channel\",\"minimum\":0},\"ext_signal\":{\"type\":\"integer\",\"description\":\"0 "
    ".. use input signal, 1 .. use output signal of channel\",\"minimum\":0},\""
    "out_interval\":{\"type\":\"integer\",\"description\":\"output pulse interval "
    "[0.1 msec]\",\"minimum\":0},\"dmi_max_time\":{\"type\":\"integer\",\"description"
    "\":\"dmi, maximum time interval between trigger events [0.1 "
    "msec]\",\"minimum\":0},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, "
    "increment in "
    "ticks\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"ttip_version\":{\"type\":\"integer\",\"description\":\"following mai"
    "n.sub.ss.sss\",\"minimum\":0},\"ext_bitmask\":{\"type\":\"integer\",\"descriptio"
    "n\":\"defines which of the internal pulse generators are to be started\","
    "\"minimum\":0},\"in_max_delay\":{\"type\":\"integer\",\"description\":\"maximum "
    "delay to output pulse before fake event is generated [0.1 msec], zero "
    "indicates that no fake events are generated\",\"minimum\":0},\"in_polarity"
    "\":{\"type\":\"integer\",\"description\":\"0 .. positive edge, 1 .. negative "
    "edge\",\"minimum\":0},\"input_usage\":{\"type\":\"integer\",\"description\":\"0 .."
    " deactivated, 1 .. just detecting and timestamping\",\"minimum\":0},\"num_"
    "channel\":{\"type\":\"integer\",\"description\":\"number of input/output chann"
    "els\",\"minimum\":0},\"dmi_min_time\":{\"type\":\"integer\",\"description\":\"dmi,"
    " minimum time interval between trigger events [0.1 "
    "msec]\",\"minimum\":0},\"output_usage\":{\"type\":\"integer\",\"description\":\"0 "
    ".. no output, 1 .. output derived from internal clock, 2 .. output "
    "derived from dmi, 3 .. output derived from external signal, 4 .. "
    "output static low, 5 .. output static "
    "high\",\"minimum\":0},\"out_polarity\":{\"type\":\"integer\",\"description\":\"0 "
    ".. positive edge, 1 .. negative "
    "edge\",\"minimum\":0},\"out_delay\":{\"type\":\"integer\",\"description\":\"output"
    " pulse initial delay after start [0.1 "
    "msec]\",\"minimum\":0}},\"title\":\"TTIP "
    "Configuration\",\"description\":\"Trigger-Timestamping-Unit/IP configurati"
    "on\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"t"
    "tip_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\"ext_delay\",\"ext"
    "_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"dmi_max_time\",\"d"
    "mi_dist_per_tick\",\"channel\",\"output_descr\",\"input_descr\",\"output_usage"
    "\",\"input_usage\",\"out_polarity\",\"out_duration\",\"out_interval\",\"out_dela"
    "y\",\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in_max_duration\","
    "\"in_max_delay\"]}"
    ,
    /* example: */
    "{\"ext_subdivider\":1,\"in_max_duration\":10000,\"output_descr\":\"Port 1 - T"
    "rigger\",\"ext_channel\":32,\"dmi_dist_per_tick\":0.0,\"ext_delay\":0,\"in_min"
    "_duration\":0,\"out_duration\":300,\"out_num_pulses\":1,\"channel\":0,\"ext_si"
    "gnal\":0,\"out_interval\":10000,\"dmi_max_time\":0,\"dmi_incr\":0,\"input_desc"
    "r\":\"Port 1 - Exposure\",\"ttip_version\":1,\"ext_bitmask\":0,\"in_max_delay\""
    ":9990,\"in_polarity\":0,\"input_usage\":1,\"num_channel\":9,\"dmi_min_time\":0"
    ",\"output_usage\":1,\"out_polarity\":0,\"out_delay\":0}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"description\":\"Details about vertex file\",\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"properties\":{\"vertex_file\":{"
    "\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"descriptio"
    "n\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"title\":\"Vertex Information\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"oneOf\":[{\"properties\":{\"voxel_type\":{\"$ref\":\"#/defin"
    "itions/voxel_type\"},\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_origin"
    "_enum\"},\"size\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\""
    "#/definitions/voxel_size_cubic\"}],\"description\":\"Size of voxels in "
    "file coordinate system.\"},\"shape_thresholds\":{\"$ref\":\"#/definitions/sh"
    "ape_thresholds\"}},\"required\":[\"size\",\"voxel_origin\",\"voxel_type\"],\"add"
    "itionalProperties\":false},{\"properties\":{\"voxel_origin\":{\"oneOf\":[{\"$r"
    "ef\":\"#/definitions/voxel_origin_enum\"},{\"description\":\"The base point "
    "of the voxel grid. Used together with <tt>voxel_size</tt> and "
    "<tt>voxel_index</tt> to compute actual point coordinates.\",\"$ref\":\"#/d"
    "efinitions/voxel_origin_point\"}]},\"size\":{\"$ref\":\"#/definitions/voxel_"
    "size\",\"description\":\"Size of voxels in file coordinate system.\"},\"size"
    "_llcs\":{\"$ref\":\"#/definitions/voxel_size\",\"description\":\"Size of "
    "voxels in a locally levelled cartesian coordinate system (xyz). This "
    "is only used for voxels based on a map projection.\"},\"voxel_type\":{\"$r"
    "ef\":\"#/definitions/voxel_type\"},\"shape_thresholds\":{\"$ref\":\"#/definiti"
    "ons/shape_thresholds\"},\"reference_point\":{\"type\":\"array\",\"description\""
    ":\"Point in WGS84 geodetic decimal degree (EPSG:4326) that was used to "
    "compute the projection distortion parameters. The coefficient order is"
    " latitude, longitude. Only voxels with corresponding geo_tag, "
    "voxel_size and reference_point can be reliably processed together. "
    "This entry is available for voxel files in projected CRS only.\",\"minIt"
    "ems\":2,\"maxItems\":2,\"items\":{\"type\":\"number\",\"maximum\":180,\"minimum\":-"
    "180}}},\"required\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_origin\""
    ",\"voxel_type\"],\"additionalProperties\":false}],\"definitions\":{\"shape_th"
    "resholds\":{\"type\":\"object\",\"description\":\"Thresholds used to compute "
    "the voxel's shape_id value.\",\"properties\":{\"plane\":{\"maximum\":1,\"type\""
    ":\"number\",\"minimum\":0,\"exclusiveMinimum\":true,\"description\":\"If the "
    "smallest eigenvalue is smaller than the median eigenvalue * "
    "plane_threshold, the voxel is considered a plane.\",\"exclusiveMaximum\":"
    "true},\"line\":{\"exclusiveMinimum\":true,\"description\":\"If the biggest "
    "eigenvalue is bigger than the median eigenvalue * line_threshold, the "
    "voxel is considered a line.\",\"minimum\":1,\"type\":\"number\"}},\"required\":"
    "[\"plane\",\"line\"]},\"voxel_type\":{\"description\":\"Whether a point in a "
    "voxel represents its center or its centroid. If type is <tt>index</tt>"
    " there is no point but only an integer voxel index.\",\"enum\":[\"center\","
    "\"centroid\",\"index\"],\"default\":\"centroid\"},\"edge_length\":{\"exclusiveMin"
    "imum\":true,\"description\":\"Length of voxel edge [m].\",\"minimum\":0,\"type"
    "\":\"number\"},\"voxel_size\":{\"type\":\"array\",\"description\":\"Size of voxels"
    ".\",\"minItems\":3,\"maxItems\":3,\"items\":{\"$ref\":\"#/definitions/edge_lengt"
    "h\"}},\"voxel_size_cubic\":{\"type\":\"number\",\"$ref\":\"#/definitions/edge_le"
    "ngth\"},\"voxel_origin_point\":{\"type\":\"array\",\"description\":\"Origin "
    "point for all voxel indices in voxel CRS.\",\"minItems\":3,\"maxItems\":3,\""
    "items\":{\"type\":\"number\"}},\"voxel_origin_enum\":{\"description\":\"Defines "
    "whether the voxel's center or a corner is placed on CRS origin <tt>(0/"
    "0/0)</tt>.\",\"enum\":[\"center\",\"corner\"],\"default\":\"corner\"}},\"title\":\"V"
    "oxel Information\",\"description\":\"Details about the voxels contained in"
    " the file\",\"$schema\":\"http://json-schema.org/draft-04/schema#\"}"
    ,
    /* example: */
    "{\"voxel_origin\":\"corner\",\"size\":[0.5971642834779395,0.5971642834779395"
    ",0.5143705304787237],\"size_llcs\":[0.5156575252891171,0.513083535668330"
    "3,0.5143705304787237],\"voxel_type\":\"centroid\",\"shape_thresholds\":{\"lin"
    "e\":6,\"plane\":0.16},\"reference_point\":[48,16]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"num_shots\":{\"type\":\"integer\",\"descript"
    "ion\":\"Number of consecutive shots to be used for averaging.\",\"minimum\""
    ":1},\"mta_zone\":{\"type\":\"integer\",\"description\":\"Fixed MTA zone for ave"
    "raging.\",\"minimum\":1},\"trim\":{\"type\":\"number\",\"description\":\"Percentag"
    "e for robust "
    "averaging.\",\"maximum\":0.5,\"minimum\":0,\"default\":0}},\"title\":\"Waveform "
    "Averaging Settings\",\"description\":\"Settings for waveform averaging\",\"$"
    "schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"num_sho"
    "ts\",\"mta_zone\"]}"
    ,
    /* example: */
    "{\"num_shots\":7,\"mta_zone\":1,\"trim\":0.05}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"sample_data_files\":{\"type\":\"array\",\"it"
    "ems\":{\"type\":\"object\",\"properties\":{\"sample_bits\":{\"type\":\"integer\",\"m"
    "aximum\":32,\"minimum\":0,\"exclusiveMinimum\":false,\"description\":\"Bitwidt"
    "h of samples (e.g. 10 bit, 12 bit)\",\"exclusiveMaximum\":false},\"sample_"
    "interval\":{\"type\":\"number\",\"description\":\"Sampling interval in seconds"
    "\",\"exclusiveMinimum\":false,\"minimum\":0},\"channel\":{\"type\":\"integer\",\"m"
    "aximum\":255,\"minimum\":0,\"exclusiveMinimum\":false,\"description\":\"Sample"
    " block channel number (255 = invalid)\",\"exclusiveMaximum\":false},\"delt"
    "a_st\":{\"type\":\"number\",\"description\":\"reserved\"},\"file_extension\":{\"ty"
    "pe\":\"string\",\"description\":\"Sample data file extension, without the "
    "leading dot\"},\"laser_wavelength\":{\"type\":\"number\",\"description\":\"Laser"
    " wavelength in meters (0 = unknown)\",\"exclusiveMinimum\":false,\"minimum"
    "\":0},\"file_uuid\":{\"type\":\"string\",\"description\":\"File's Universally "
    "Unique Identifier (RFC "
    "4122)\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"}},\"required\":[\"channel\",\"channel_name\",\"sample_interval\""
    ",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"]}},\"rang"
    "e_offset_waveform_samples_m\":{\"type\":\"number\",\"description\":\"Calibrate"
    "d device specific range offset for waveform samples in meters.\"},\"samp"
    "le_block_file\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"str"
    "ing\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"]},\"range_offset_m\":{\"type\":\"number\",\"description\":\"Calibrated device"
    " specific range offset for waveform analysis by system response "
    "fitting in meters.\"}},\"title\":\"Waveform "
    "Information\",\"description\":\"Details about waveform files\",\"$schema\":\"h"
    "ttp://json-schema.org/draft-04/schema#\",\"required\":[\"sample_block_file"
    "\",\"sample_data_files\"]}"
    ,
    /* example: */
    "{\"range_offset_waveform_samples_m \":7.283,\"sample_block_file\":{\"file_u"
    "uid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\"},\"s"
    "ample_data_files\":[{\"file_extension\":\"sp0\",\"sample_interval\":1.00503e-"
    "09,\"file_uuid\":\"da084413-e3e8-4655-a122-071de8490d8e\",\"delta_st\":0,\"sa"
    "mple_bits\":12,\"laser_wavelength\":0,\"channel\":0,\"channel_name\":\"high_po"
    "wer\"},{\"file_extension\":\"sp1\",\"sample_interval\":1.00503e-09,\"file_uuid"
    "\":\"93585b5e-5ea9-43a1-947b-e7ba3be642d2\",\"delta_st\":0,\"sample_bits\":12"
    ",\"laser_wavelength\":0,\"channel\":1,\"channel_name\":\"low_power\"},{\"file_e"
    "xtension\":\"sp5\",\"sample_interval\":1.00503e-09,\"file_uuid\":\"9d2298c4-10"
    "36-464f-b5cb-1cf8e517f3a0\",\"delta_st\":0,\"sample_bits\":12,\"laser_wavele"
    "ngth\":0,\"channel\":5,\"channel_name\":\"wwf\"}],\"range_offset_m\":3.1415}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"description\":\"Scanner settings for waveform output\",\""
    "$schema\":\"http://json-schema.org/draft-04/schema#\",\"title\":\"Waveform S"
    "ettings\",\"items\":{\"type\":\"object\",\"properties\":{\"logic_expression\":{\"t"
    "ype\":\"string\",\"description\":\"Logic expression of smart waveforms "
    "filter\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold "
    "for deviation less than "
    "[1]\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample block,"
    " e.g.: wfm, wwf\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform "
    "output "
    "enabled\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold"
    " for range greater than "
    "[m]\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "amplitude less than "
    "[dB]\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "range less than "
    "[m]\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask for"
    " channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, "
    "...\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform"
    " output enabled\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\""
    "Threshold for deviation greater than "
    "[1]\"}},\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_mask\"]}}"
    ,
    /* example: */
    "[{\"sbl_name\":\"wfm\",\"enabled\":true,\"pass_rng_greater\":9.27,\"pass_ampl_l"
    "ess\":5.0,\"pass_rng_less\":13.11,\"pass_ampl_greater\":1.0,\"smart_enabled\""
    ":true,\"channel_idx_mask\":11},{\"sbl_name\":\"wwf\",\"enabled\":false,\"channe"
    "l_idx_mask\":32}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"result\":{\"type\":\"object\",\"properties\":"
    "{\"angle\":{\"type\":\"array\",\"description\":\"[deg]\",\"items\":{\"type\":\"number"
    "\"}},\"amplitude_sigma\":{\"type\":\"array\",\"description\":\"[dB]\",\"items\":{\"t"
    "ype\":\"number\"}},\"amplitude_offset\":{\"type\":\"array\",\"description\":\"[dB]"
    "\",\"items\":{\"type\":\"number\"}},\"amplitude_mean\":{\"type\":\"array\",\"descrip"
    "tion\":\"[dB]\",\"items\":{\"type\":\"number\"}},\"range_sigma\":{\"type\":\"array\","
    "\"description\":\"[m]\",\"items\":{\"type\":\"number\"}},\"timestamp\":{\"type\":\"ar"
    "ray\",\"description\":\"[s]\",\"items\":{\"type\":\"number\"}},\"range_mean\":{\"typ"
    "e\":\"array\",\"description\":\"[m]\",\"items\":{\"type\":\"number\"}}},\"required\":"
    "[\"angle\",\"range_mean\",\"range_sigma\",\"amplitude_mean\",\"amplitude_sigma\""
    ",\"amplitude_offset\"]},\"filter\":{\"type\":\"object\",\"properties\":{\"angle\":"
    "{\"type\":\"array\",\"description\":\"[deg]\",\"items\":{\"type\":\"number\"}},\"rang"
    "e_max\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":{\"type\":\"number\"}},"
    "\"range_min\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":{\"type\":\"numbe"
    "r\"}},\"amplitude_max\":{\"type\":\"array\",\"description\":\"[dB]\",\"items\":{\"ty"
    "pe\":\"number\"}}},\"required\":[\"angle\",\"range_min\",\"range_max\",\"amplitude"
    "_max\"]},\"settings\":{\"type\":\"object\",\"properties\":{\"amplitude\":{\"type\":"
    "\"object\",\"properties\":{\"sigma_factor\":{\"type\":\"number\"},\"additive_valu"
    "e\":{\"type\":\"number\"}},\"required\":[\"sigma_factor\",\"additive_value\"]},\"r"
    "ange\":{\"type\":\"object\",\"properties\":{\"sigma_factor\":{\"type\":\"number\"},"
    "\"additive_value\":{\"type\":\"number\"}},\"required\":[\"sigma_factor\",\"additi"
    "ve_value\"]}},\"required\":[\"range\",\"amplitude\"]}},\"title\":\"Window "
    "Analysis\",\"description\":\"Window analysis data estimated from scandata "
    "and resulting filter parameters\",\"$schema\":\"http://json-schema.org/dra"
    "ft-04/schema#\",\"required\":[\"result\",\"filter\",\"settings\"]}"
    ,
    /* example: */
    "{\"result\":{\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,"
    "15.9],\"amplitude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.436"
    "2353,0.4315141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"amp"
    "litude_offset\":[1.9,1.9],\"amplitude_mean\":[5.347396,5.263155,5.224655,"
    "5.179926,5.097782,5.116479,5.051756,4.983473,5.007885,5.002441,4.982],"
    "\"range_sigma\":[0.01869652,0.02151435,0.01747969,0.01918765,0.01945776,"
    "0.01934862,0.01955329,0.02225589,0.02229977,0.01899122,0.02009433],\"ti"
    "mestamp\":[408.4441,411.4443],\"range_mean\":[0.1105621,0.1079564,0.10870"
    "88,0.1067261,0.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.105844"
    "5,0.1031261]},\"filter\":{\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15"
    ".6,15.7,15.8,15.9],\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0."
    "429,0.43,0.431,0.431,0.432],\"range_min\":[-0.208,-0.21,-0.212,-0.214,-0"
    ".216,-0.218,-0.219,-0.221,-0.223,-0.225,-0.227],\"amplitude_max\":[8.04,"
    "8.01,7.99,7.96,7.93,7.9,7.88,7.85,7.83,7.8,7.78]},\"settings\":{\"amplitu"
    "de\":{\"sigma_factor\":4,\"additive_value\":1.0},\"range\":{\"sigma_factor\":8,"
    "\"additive_value\":0.1}}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"properties\":{\"amplitude\":{\"type\":\"object\",\"descripti"
    "on\":\"Amplitude axis of correction table\",\"required\":[\"minimum\",\"maximu"
    "m\",\"entries\"],\"properties\":{\"maximum\":{\"type\":\"number\",\"description\":\""
    "Maximum amplitude in "
    "dB\",\"minimum\":0.0},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "amplitude in "
    "dB\",\"minimum\":0.0},\"entries\":{\"type\":\"integer\",\"description\":\"Number "
    "of amplitude entries\",\"minimum\":1}}},\"slices\":{\"type\":\"array\",\"items\":"
    "{\"type\":\"object\",\"description\":\"Window echo correction parameter slice"
    "\",\"required\":[\"amplitude\",\"table\"],\"properties\":{\"amplitude\":{\"type\":\""
    "number\",\"description\":\"Window echo amplitude of slice in "
    "dB\"},\"table\":{\"type\":\"array\",\"description\":\"Correction table "
    "(dimension defined by the 'amplitude' and 'range' "
    "objects)\",\"minItems\":1,\"items\":{\"type\":\"array\",\"description\":\"Table "
    "row (= amplitude "
    "axis)\",\"minItems\":1,\"items\":{\"type\":\"array\",\"description\":\"Table "
    "column (= range axis)\",\"minItems\":3,\"maxItems\":3,\"items\":{\"type\":\"numb"
    "er\",\"description\":\"Table cell (item 0: amplitude in dB, 1: range in m,"
    " 2: flags)\"}}}}}}},\"range\":{\"type\":\"object\",\"description\":\"Range axis "
    "of correction table\",\"required\":[\"minimum\",\"maximum\",\"entries\"],\"prope"
    "rties\":{\"maximum\":{\"type\":\"number\",\"description\":\"Maximum range in m\","
    "\"maximum\":2.0,\"minimum\":-2.0},\"minimum\":{\"type\":\"number\",\"description\""
    ":\"Minimum range in m\",\"maximum\":2.0,\"minimum\":-2.0},\"entries\":{\"type\":"
    "\"integer\",\"description\":\"Number of range "
    "entries\",\"minimum\":1}}}},\"title\":\"Window Echo "
    "Correction\",\"description\":\"Correction parameters for window glass echo"
    "es\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"required\":[\"a"
    "mplitude\",\"range\",\"slices\"]}"
    ,
    /* example: */
    "{\"amplitude\":{\"maximum\":20,\"minimum\":2,\"entries\":128},\"slices\":[{\"ampl"
    "itude\":1.5,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]},{\"amplitude"
    "\":2.0,\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]]}],\"range\":{\"maxim"
    "um\":1.5060822940732335,\"minimum\":-1.5060822940732335,\"entries\":128}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);

#endif // RDB_81EBCB65_FE94_471E_8D25_2B4D71CC91B1
